### Mission

Because training and executing models depends on installing compiled code, which must be compatible with drivers and hardware, we must:

- Target specific environments (Operating Systems, hardware and driver configurations)
- Make it clear to users that we support those, and make no promises outside them.
- Have a semi-automated way to test for regressions each time we deploy

## Supported environments

| OS           | CPU | GPU | GPU DRIVER |
| ------------ | --- | --- | ---------- |
| MacOS        |     |     |            |
| Windows      |     |     |            |
| Linux Ubuntu |     |     |            |
